@@ -484,7 +484,7 @@ class ApigatewayClient(AbstractClient):
 
 
     def DescribeApi(self, request):
-        """This API is used to query the details of an API deployed in API Gateway.
+        """This API (`DescribeApi`) is used to query the details of the APIs users manage via Tencent Cloud API Gateway.
 
         :param request: Request instance for DescribeApi.
         :type request: :class:`tencentcloud.apigateway.v20180808.models.DescribeApiRequest`
